/* 
 * Mirai. Copyright (C) 2024 Vyn
 * This file is licensed under version 3 of the GNU General Public License (GPL-3.0-only)
 * The license can be found in the LICENSE file or at https://www.gnu.org/licenses/gpl-3.0.txt
 */

#ifndef MIRAI_TASKSFILE_H
#define MIRAI_TASKSFILE_H

#include <algorithm>
#include <ctime>
#include <fstream>
#include <iomanip>
#include <iostream>
#include <memory>
#include <ostream>
#include <regex>
#include <sstream>
#include <stdexcept>
#include <string>
#include <vector>
#include "TaskItem.h"
#include "using.h"
#include "utils.h"

namespace mirai {

	struct TasksFileConstructor {
		const std::string& name;
		const std::string& path;
		std::vector<TaskItem> tasks;
	};

	class TasksFile {

	public:

		TasksFile(TasksFileConstructor params);

		void addTask(std::string text, std::string date);
		void removeTask(const TaskItem* taskToRemove);
		void processTaskMetaData(const TaskItem& task);
		void sortByDate();

		const std::string& getName() const;
		const std::string& getPath() const;
		TasksPtrs& getTasks();
		Tags& getTags();
	
	private:
		std::string name;
		std::string path;
		TasksPtrs tasks;
		Tags tags;
	};
}

#endif
